@@ -2,6 +2,7 @@
 
 import logging
 import os
+import re
 import shutil
 import tempfile
 import urllib
@@ -10,6 +11,8 @@ import zipfile
 
 logger = logging.getLogger(__name__)
 
+rx_setuptools = re.compile(os.path.join('^.*', '(setuptools|distribute)-.*?-py\d.\d.egg$'))
+
 
 def copytree(src, dst, symlinks=0, allowed_basenames=None, exclude=[]):
     """Local implementation of shutil's copytree function.
@@ -200,12 +203,17 @@ class Recipe(zc.recipe.egg.Eggs):
 
     def write_pkg_resources(self, ws, d):
         """Write original pkg_resources.py file from setuptools egg."""
-        setuptools_eggs = [e for e in ws.entries if 'setuptools' in e]
+        setuptools_eggs = [e for e in ws.entries if rx_setuptools.match(e)]
         assert len(setuptools_eggs) == 1, "setuptools not found"
-        egg_contents = zipfile.ZipFile(setuptools_eggs[0])
-        pkg_resources = open(os.path.join(d, 'pkg_resources.py'), "w")
-        pkg_resources.write(egg_contents.read('pkg_resources.py'))
-        pkg_resources.close()
+        if os.path.isdir(setuptools_eggs[0]):
+            src = os.path.join(setuptools_eggs[0], 'pkg_resources.py')
+            dst = os.path.join(d, 'pkg_resources.py')
+            shutil.copyfile(src, dst)
+        else:
+            egg_contents = zipfile.ZipFile(setuptools_eggs[0])
+            pkg_resources = open(os.path.join(d, 'pkg_resources.py'), "w")
+            pkg_resources.write(egg_contents.read('pkg_resources.py'))
+            pkg_resources.close()
 
     def copy_packages(self, ws, lib):
         """Copy egg contents to lib-directory."""
